==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/bg/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Модулът е успешно деактивиран!',
    '
Module successfully enabled!
' => 'Модулът е успешно активиран!',
    '
No active Professional Edition license found!
' => 'Не е намерен активен лиценз за професионално издание!',
    '
PROFESSIONAL EDITION
' => 'ПРОФЕСИОНАЛНО ИЗДАНИЕ',
    '
The license could not be activated:
' => 'Лицензът не може да бъде активиран:',
    '
The license was successfully activated!

' => 'Лицензът беше успешно активиран!',
    '
The license was successfully removed!

' => 'Лицензът беше премахнат успешно!',
    '--- Disable module: {moduleId} ---

' => '--- Деактивиране на модул: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Активиране на модул: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong> Активирайте </strong> вашата Професионална Версия',
    'Add purchased module by licence key' => 'Добавете закупения модул чрез лицензен ключ',
    'All {moduleId} module content will be deleted. Continue?' => 'Цялото съдържание на модула {moduleId} ще бъде изтрито. Продължи?',
    'Buy' => 'Купи',
    'Buy (%price%)' => 'Купи (%price%)',
    'Could not connect to licence server!' => 'Не може да бъде осъществена връзка с лицензен сървър!',
    'Could not extract module!' => 'Неуспешно извличане на модул!',
    'Could not remove old module path!' => 'Неуспешно премахване на стария път на модула!',
    'Could not update licence. Error: ' => 'Неуспешно актуализиране на лиценза. Грешка:',
    'Download of module failed!' => 'Изтеглянето на модула не бе успешно!',
    'Edit licence' => 'Редактиране на лиценз',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Ако този модул е допълнително маркиран като <strong>"Общност"</strong>, той не е нито тестван, нито контролиран от екипа на проекта HumHub.',
    'Install' => 'Инсталирай',
    'Installed' => 'Инсталирани',
    'Installing module...' => 'Инсталиране на модул...',
    'Latest version:' => 'Последна версия:',
    'Licence Key:' => 'Лицензен ключ:',
    'Licence key' => 'Лицензен ключ',
    'Licenced for max. {number} users.' => 'Лицензиран за макс. {number} потребители.',
    'Licenced to:' => 'Лицензиран за:',
    'Marketplace' => 'Пазар',
    'Max. users:' => 'Макс. потребители:',
    'Module directory %modulePath% is not writeable!' => 'В модулна директория %modulePath% не може да се записва!',
    'Module download failed! (%error%)' => 'Изтеглянето на модула не бе успешно! (%error%)',
    'Module not found or activated!
' => 'Модулът не е намерен или активиран!',
    'Module not found!
' => 'Модулът не е намерен!',
    'More info' => 'Повече информация',
    'No compatible module version found!' => 'Не е намерена съвместима версия на модула!',
    'No license key? Find out more about the {pro} or contact us.' => 'Няма лицензен ключ? Научете повече за {pro} или се свържете с нас.',
    'No purchased modules found!' => 'Не са намерени закупени модули!',
    'Ok' => 'Ок',
    'Professional Edition is activated!' => 'Професионалната версия е активирана!',
    'Register' => 'Регистрирам',
    'Remove licence key' => 'Премахнете лицензионния ключ',
    'Save and update' => 'Запазване и актуализиране',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Проектът HumHub не гарантира функционалността, качеството или непрекъснатото развитие на този модул.',
    'Third-party' => 'Трета страна',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Модулите на трети страни не са обхванати от споразумения за Професионална Версия.',
    'Third-party disclaimer' => 'Отказ от отговорност на трета страна',
    'This Module was developed by a third-party.' => 'Този модул е разработен от трета страна.',
    'Update' => 'Актуализиране',
    'Upgrade to Professional Edition' => 'Надстройте до Професионална Версия',
    'Version:' => 'Версия:',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!
' => '',
    'Featured' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/bg/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Модулът е успешно деактивиран!',
    '
Module successfully enabled!
' => 'Модулът е успешно активиран!',
    '
No active Professional Edition license found!
' => 'Не е намерен активен лиценз за професионално издание!',
    '
The license could not be activated:
' => 'Лицензът не може да бъде активиран:',
    '
The license was successfully activated!

' => 'Лицензът беше успешно активиран!',
    '
The license was successfully removed!

' => 'Лицензът беше премахнат успешно!',
    '--- Disable module: {moduleId} ---

' => '--- Деактивиране на модул: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Активиране на модул: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong> Активирайте </strong> вашата Професионална Версия',
    'Activate' => 'Активиране',
    'Activated' => 'Активиран',
    'Add purchased module by licence key' => 'Добавете закупения модул чрез лицензен ключ',
    'All' => 'Всички',
    'All {moduleId} module content will be deleted. Continue?' => 'Цялото съдържание на модула {moduleId} ще бъде изтрито. Продължи?',
    'Buy' => 'Купи',
    'Buy (%price%)' => 'Купи (%price%)',
    'Configure' => 'Настройване',
    'Could not connect to licence server!' => 'Не може да бъде осъществена връзка с лицензен сървър!',
    'Could not extract module!' => 'Неуспешно извличане на модул!',
    'Could not find requested module!' => 'Заявеният модел не може да бъде намерен!',
    'Could not remove old module path!' => 'Неуспешно премахване на стария път на модула!',
    'Could not update licence. Error: ' => 'Неуспешно актуализиране на лиценза. Грешка:',
    'Download of module failed!' => 'Изтеглянето на модула не бе успешно!',
    'Edit licence' => 'Редактиране на лиценз',
    'General Settings' => 'Основни Настройки',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Ако този модул е допълнително маркиран като <strong>"Общност"</strong>, той не е нито тестван, нито контролиран от екипа на проекта HumHub.',
    'Information' => 'Информация',
    'Install' => 'Инсталирай',
    'Installed' => 'Инсталирани',
    'Latest version:' => 'Последна версия:',
    'Licence Key:' => 'Лицензен ключ:',
    'Licence key' => 'Лицензен ключ',
    'Licenced for max. {number} users.' => 'Лицензиран за макс. {number} потребители.',
    'Licenced to:' => 'Лицензиран за:',
    'Marketplace' => 'Пазар',
    'Max. users:' => 'Макс. потребители:',
    'Module directory %modulePath% is not writeable!' => 'В модулна директория %modulePath% не може да се записва!',
    'Module download failed! (%error%)' => 'Изтеглянето на модула не бе успешно! (%error%)',
    'Module not found or activated!
' => 'Модулът не е намерен или активиран!',
    'Module not found!
' => 'Модулът не е намерен!',
    'More info' => 'Повече информация',
    'New' => 'Нов',
    'No compatible module version found!' => 'Не е намерена съвместима версия на модула!',
    'No license key? Find out more about the {pro} or contact us.' => 'Няма лицензен ключ? Научете повече за {pro} или се свържете с нас.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Все още няма инсталирани модули. Инсталирайте модул, за да подобрите функционалността!',
    'No purchased modules found!' => 'Не са намерени закупени модули!',
    'Ok' => 'Ок',
    'Professional Edition is activated!' => 'Професионалната версия е активирана!',
    'Register' => 'Регистрирам',
    'Remove licence key' => 'Премахнете лицензионния ключ',
    'Save and update' => 'Запазване и актуализиране',
    'Search' => 'Търсене',
    'Settings' => 'Настройки',
    'Tags' => 'Етикети',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Проектът HumHub не гарантира функционалността, качеството или непрекъснатото развитие на този модул.',
    'Third-party' => 'Трета страна',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Модулите на трети страни не са обхванати от споразумения за Професионална Версия.',
    'Third-party disclaimer' => 'Отказ от отговорност на трета страна',
    'This Module was developed by a third-party.' => 'Този модул е разработен от трета страна.',
    'Update' => 'Актуализиране',
    'Update successful' => 'Актуализацията е успешна',
    'Upgrade to Professional Edition' => 'Надстройте до Професионална Версия',
    'Version:' => 'Версия:',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate now' => '',
    'Add Licence Key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Search...' => '',
    'Stop updating' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
